# accelphys
A package for basic accelerator physics. May also be useful in other areas of study but accelerator physics is the main focus area.

# Installation
The package can be installed in editable mode by running the following command in the terminal:

```bash
git clone https://github.com/jako4295/accelphys.git
pip install -e .
```